character string. The column name with the country assignment
of each record. Default = "country".
Details
Country names are standardized using an exact matching against a
list of country names in several languages from International Organization for Standardization. If any unmatched
names remain, a fuzzy matching algorithm is used to find potential
candidates for each misspelled countries names.
See Also
Other prefilter:
bdc_basisOfRecords_notStandard(),
bdc_coordinates_country_inconsistent(),
bdc_coordinates_empty(),
bdc_coordinates_from_locality(),
bdc_coordinates_outOfRange(),
bdc_coordinates_transposed(),
bdc_scientificName_empty()
if (FALSE) {
country <- c("BOLIVIA", "bolivia", "Brasil", "Brazil", "BREZIL")
x <- data.frame(country)
bdc_country_standardized(
data = x,
country = "country")
}