bdc_summary_col: Create or update the column summarizing the results of data quality tests
Description
This function creates or updates the column ".summary" summarizing the
results of data quality tests (i.e., columns starting with "."). Records that
have failed in at least one test are flagged for further inspection (i.e.,
flagged as "FALSE") in the ".summary" column.
Usage
bdc_summary_col(data)
Value
A data.frame containing a new or an updated column ".summary".
Arguments
data
data.frame. Containing the results of data quality tests (i.e.,
columns starting with ".").
Details
If existing, the column ".summary" will be removed and then updated
considering all test names available in the supplied database.